searchData={"items":[{"type":"module","title":"Chargebeex","doc":"Chargebeex is an Elixir implementation of [Chargebee\nAPI](https://apidocs.chargebee.com/docs/api).","ref":"Chargebeex.html"},{"type":"module","title":"Installation - Chargebeex","doc":"The package can be installed by adding `chargebeex` to your list of\ndependencies in `mix.exs`:\n\n```elixir\n# mix.exs\ndef deps do\n[\n  {:chargebeex, \"~> 0.6.0\"}\n]\nend\n```","ref":"Chargebeex.html#module-installation"},{"type":"module","title":"Configuration - Chargebeex","doc":"Chargebeex can be configured using\n[Config](https://hexdocs.pm/elixir/1.12/Config.html) or environment variables.","ref":"Chargebeex.html#module-configuration"},{"type":"module","title":"Config - Chargebeex","doc":"```elixir\nconfig :chargebeex,\n  namespace: \"my-namespace\",\n  api_key: \"my-api-key\"\n\n```","ref":"Chargebeex.html#module-config"},{"type":"module","title":"Environment variables - Chargebeex","doc":"```\nexport CHARGEBEEX_API_KEY=my-api-key\nexport CHARGEBEEX_NAMESPACE=my-namespace\n```","ref":"Chargebeex.html#module-environment-variables"},{"type":"module","title":"Usage - Chargebeex","doc":"```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\")\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list()\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"})\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\")\n```","ref":"Chargebeex.html#module-usage"},{"type":"module","title":"With Multiple Sites - Chargebeex","doc":"To interact with multiple Chargebee sites, scope your Chargebee config to an\natom or module representing the site. For example, if you have a site called \"my_site\", you can do the following:\n\n```elixir\nconfig :chargebeex, :my_site,\n  namespace: \"my-other-namespace\",\n  api_key: \"my-second-api-key\"\n```\n\nAnd specify the site when calling the API:\n```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\", site: :my_site)\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list(site: :my_site)\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"}, site: :my_site)\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\", site: :my_site)\n```","ref":"Chargebeex.html#module-with-multiple-sites"},{"type":"module","title":"Custom Fields - Chargebeex","doc":"Chargebee provides a way to add user-specific fields for resources like\nCustomer, Subscriptions, ... called [Custom\nFields](https://www.chargebee.com/docs/2.0/custom_fields.html).\n\nThese fields are prepended with the `cf_` prefix. These fields can be accessed\nin the special `custom_fields` field of the structure. Please note Custom\nFields are only available for Customers, Subscriptions, Product Families,\nPlans, Addons and Price Points.\n\n#### Example:\n\n```elixir\niex> Chargebeex.Customer.retrieve(\"barbaz\")\n{:ok, %Chargebeex.Customer{\n   id: \"barbaz\",\n   allow_direct_debit: false,\n   custom_fields: %{\n     \"cf_my_custom_field\" => \"foobar\"\n   },\n   [...]}\n}\n```","ref":"Chargebeex.html#module-custom-fields"},{"type":"module","title":"Extra Resources - Chargebeex","doc":"Some ressources can have extra infos returned along them. For example, when\nquerying a Customer, if any card or subscription is linked to this customer,\nthese resources will also be returned. For internal API simplification, these\nfields can be accessed in the `resources` field of the structure.\n\n#### Example:\n\n```elixir\niex> Chargebeex.Customer.retrieve(\"barbaz\")\n{:ok, %Chargebeex.Customer{\n   id: \"barbaz\",\n   allow_direct_debit: false,\n    resources: %{\n      \"card\" => %Chargebeex.Card{\n        billing_addr1: \"my_address\",\n        billing_addr2: nil,\n        billing_city: \"Paris\",\n        ...\n        }\n    }\n   [...]}\n}\n```","ref":"Chargebeex.html#module-extra-resources"},{"type":"module","title":"Run tests - Chargebeex","doc":"```sh\nmix test\n```","ref":"Chargebeex.html#module-run-tests"},{"type":"module","title":"License - Chargebeex","doc":"MIT","ref":"Chargebeex.html#module-license"},{"type":"module","title":"Chargebeex.BankAccount","doc":"","ref":"Chargebeex.BankAccount.html"},{"type":"function","title":"Chargebeex.BankAccount.build/2","doc":"","ref":"Chargebeex.BankAccount.html#build/2"},{"type":"type","title":"Chargebeex.BankAccount.t/0","doc":"","ref":"Chargebeex.BankAccount.html#t:t/0"},{"type":"module","title":"Chargebeex.BillingAddress","doc":"","ref":"Chargebeex.BillingAddress.html"},{"type":"function","title":"Chargebeex.BillingAddress.build/2","doc":"","ref":"Chargebeex.BillingAddress.html#build/2"},{"type":"type","title":"Chargebeex.BillingAddress.t/0","doc":"","ref":"Chargebeex.BillingAddress.html#t:t/0"},{"type":"module","title":"Chargebeex.QuotedSubscription","doc":"Struct that represent a Chargebee's API quoted subscription.","ref":"Chargebeex.QuotedSubscription.html"},{"type":"function","title":"Chargebeex.QuotedSubscription.build/2","doc":"","ref":"Chargebeex.QuotedSubscription.html#build/2"},{"type":"type","title":"Chargebeex.QuotedSubscription.t/0","doc":"","ref":"Chargebeex.QuotedSubscription.html#t:t/0"},{"type":"behaviour","title":"Chargebeex.Resource","doc":"Generic macro implemented by most of the Chargebee resources. Provides\n  whenever it is possible retrieve/create/list/update/delete actions for each\n  resource.","ref":"Chargebeex.Resource.html"},{"type":"callback","title":"Chargebeex.Resource.build/1","doc":"Build a raw data map into in an internal structure.","ref":"Chargebeex.Resource.html#c:build/1"},{"type":"callback","title":"Chargebeex.Resource.create/1","doc":"Create a resource","ref":"Chargebeex.Resource.html#c:create/1"},{"type":"callback","title":"Chargebeex.Resource.create/2","doc":"","ref":"Chargebeex.Resource.html#c:create/2"},{"type":"callback","title":"Chargebeex.Resource.delete/1","doc":"Delete a resource","ref":"Chargebeex.Resource.html#c:delete/1"},{"type":"callback","title":"Chargebeex.Resource.delete/2","doc":"","ref":"Chargebeex.Resource.html#c:delete/2"},{"type":"callback","title":"Chargebeex.Resource.list/1","doc":"List a resource","ref":"Chargebeex.Resource.html#c:list/1"},{"type":"callback","title":"Chargebeex.Resource.list/2","doc":"","ref":"Chargebeex.Resource.html#c:list/2"},{"type":"callback","title":"Chargebeex.Resource.retrieve/1","doc":"Retrieve a resource","ref":"Chargebeex.Resource.html#c:retrieve/1"},{"type":"callback","title":"Chargebeex.Resource.retrieve/2","doc":"","ref":"Chargebeex.Resource.html#c:retrieve/2"},{"type":"callback","title":"Chargebeex.Resource.update/2","doc":"Update a resource","ref":"Chargebeex.Resource.html#c:update/2"},{"type":"callback","title":"Chargebeex.Resource.update/3","doc":"","ref":"Chargebeex.Resource.html#c:update/3"},{"type":"behaviour","title":"Chargebeex.ClientBehaviour","doc":"Define the callbacks for a client to get the data from Chargebee.","ref":"Chargebeex.ClientBehaviour.html"},{"type":"callback","title":"Chargebeex.ClientBehaviour.get/3","doc":"","ref":"Chargebeex.ClientBehaviour.html#c:get/3"},{"type":"callback","title":"Chargebeex.ClientBehaviour.post/3","doc":"","ref":"Chargebeex.ClientBehaviour.html#c:post/3"},{"type":"module","title":"Chargebeex.AttachedItem","doc":"Struct that represent a Chargebee's API attached item resource.","ref":"Chargebeex.AttachedItem.html"},{"type":"function","title":"Chargebeex.AttachedItem.build/2","doc":"","ref":"Chargebeex.AttachedItem.html#build/2"},{"type":"type","title":"Chargebeex.AttachedItem.channel/0","doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.AttachedItem.html#t:channel/0"},{"type":"type","title":"Chargebeex.AttachedItem.charge_event/0","doc":"\"subscription_creation\" | \"subscription_trial_start\" | \"plan_activation\" |\n\"subscription_activation\" | \"contract_termination\" | \"on_demand\"","ref":"Chargebeex.AttachedItem.html#t:charge_event/0"},{"type":"function","title":"Chargebeex.AttachedItem.list/3","doc":"Allows to list Attached Items\n\nAvailable filters can be found here: https://apidocs.eu.chargebee.com/docs/api/attached_items#list_attached_items","ref":"Chargebeex.AttachedItem.html#list/3"},{"type":"function","title":"Examples - Chargebeex.AttachedItem.list/3","doc":"iex> filters = %{limit: 2}\n    iex(2)> Chargebeex.AttachedItem.list(filters)\n    {:ok, [%Chargebeex.AttachedItem{...}, %Chargebeex.AttachedItem{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.AttachedItem.html#list/3-examples"},{"type":"type","title":"Chargebeex.AttachedItem.status/0","doc":"\"active\" | \"archived\" | \"deleted\"","ref":"Chargebeex.AttachedItem.html#t:status/0"},{"type":"type","title":"Chargebeex.AttachedItem.t/0","doc":"","ref":"Chargebeex.AttachedItem.html#t:t/0"},{"type":"type","title":"Chargebeex.AttachedItem.type/0","doc":"\"recommended\" | \"mandatory\" | \"optional\"","ref":"Chargebeex.AttachedItem.html#t:type/0"},{"type":"module","title":"Chargebeex.Card","doc":"","ref":"Chargebeex.Card.html"},{"type":"function","title":"Chargebeex.Card.build/2","doc":"","ref":"Chargebeex.Card.html#build/2"},{"type":"type","title":"Chargebeex.Card.t/0","doc":"","ref":"Chargebeex.Card.html#t:t/0"},{"type":"module","title":"Chargebeex.Customer","doc":"","ref":"Chargebeex.Customer.html"},{"type":"function","title":"Chargebeex.Customer.assign_payment_role/3","doc":"","ref":"Chargebeex.Customer.html#assign_payment_role/3"},{"type":"function","title":"Chargebeex.Customer.build/1","doc":"","ref":"Chargebeex.Customer.html#build/1"},{"type":"function","title":"Chargebeex.Customer.build/2","doc":"","ref":"Chargebeex.Customer.html#build/2"},{"type":"function","title":"Chargebeex.Customer.change_billing_date/3","doc":"","ref":"Chargebeex.Customer.html#change_billing_date/3"},{"type":"function","title":"Chargebeex.Customer.clear_personal_data/2","doc":"","ref":"Chargebeex.Customer.html#clear_personal_data/2"},{"type":"function","title":"Chargebeex.Customer.collect_payment/3","doc":"","ref":"Chargebeex.Customer.html#collect_payment/3"},{"type":"function","title":"Chargebeex.Customer.create/1","doc":"Allows to create a Customer","ref":"Chargebeex.Customer.html#create/1"},{"type":"function","title":"Examples - Chargebeex.Customer.create/1","doc":"iex> Chargebeex.Customer.create(%{company: \"MyCompany\"})\n      {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{},\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#create/1-examples"},{"type":"function","title":"Chargebeex.Customer.create/2","doc":"","ref":"Chargebeex.Customer.html#create/2"},{"type":"function","title":"Chargebeex.Customer.delete/2","doc":"Deletes a Customer","ref":"Chargebeex.Customer.html#delete/2"},{"type":"function","title":"Examples - Chargebeex.Customer.delete/2","doc":"iex> Chargebeex.Customer.delete(\"169ljDT1Op0yuxET\")\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyUpdatedCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#delete/2-examples"},{"type":"function","title":"Chargebeex.Customer.delete_relationship/2","doc":"","ref":"Chargebeex.Customer.html#delete_relationship/2"},{"type":"function","title":"Chargebeex.Customer.hierarchy/3","doc":"","ref":"Chargebeex.Customer.html#hierarchy/3"},{"type":"function","title":"Chargebeex.Customer.list/1","doc":"Allows to list Customers\n\nAvailable filters can be found here: https://apidocs.chargebee.com/docs/api/customers#list_customers","ref":"Chargebeex.Customer.html#list/1"},{"type":"function","title":"Examples - Chargebeex.Customer.list/1","doc":"iex> filters = %{limit: 2}\n    iex(2)> Chargebeex.Customer.list(filters)\n    {:ok, [%Chargebeex.Customer{...}, %Chargebeex.Customer{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.Customer.html#list/1-examples"},{"type":"function","title":"Chargebeex.Customer.list/2","doc":"","ref":"Chargebeex.Customer.html#list/2"},{"type":"function","title":"Chargebeex.Customer.merge/3","doc":"","ref":"Chargebeex.Customer.html#merge/3"},{"type":"function","title":"Chargebeex.Customer.move/3","doc":"","ref":"Chargebeex.Customer.html#move/3"},{"type":"function","title":"Chargebeex.Customer.record_excess_payment/3","doc":"","ref":"Chargebeex.Customer.html#record_excess_payment/3"},{"type":"function","title":"Chargebeex.Customer.relationships/3","doc":"","ref":"Chargebeex.Customer.html#relationships/3"},{"type":"function","title":"Chargebeex.Customer.retrieve/1","doc":"Allows to retrieve a Customer","ref":"Chargebeex.Customer.html#retrieve/1"},{"type":"function","title":"Examples - Chargebeex.Customer.retrieve/1","doc":"iex> Chargebeex.Customer.retrieve(\"AzyzkCSvjSUpY4xuB\")\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#retrieve/1-examples"},{"type":"function","title":"Chargebeex.Customer.retrieve/2","doc":"","ref":"Chargebeex.Customer.html#retrieve/2"},{"type":"type","title":"Chargebeex.Customer.t/0","doc":"","ref":"Chargebeex.Customer.html#t:t/0"},{"type":"function","title":"Chargebeex.Customer.update/2","doc":"Allows to update a Customer","ref":"Chargebeex.Customer.html#update/2"},{"type":"function","title":"Examples - Chargebeex.Customer.update/2","doc":"iex> Chargebeex.Customer.update(\"169ljDT1Op0yuxET\", %{company: \"MyUpdatedCompany\"})\n    {:ok, %Chargebeex.Customer{\n        allow_direct_debit: false,\n        auto_collection: \"on\",\n        business_customer_without_vat_number: false,\n        card_status: \"no_card\",\n        channel: \"web\",\n        company: \"MyUpdatedCompany\",\n        created_at: 1648489755,\n        custom_fields: %{\n          \"cf_internal_identifier\" => \"1234\",\n          \"cf_other_custom_field\" => \"foobar\"\n        },\n        deleted: false,\n        email: nil,\n        excess_payments: 0,\n        id: \"169ljDT1Op0yuxET\",\n        locale: nil,\n        net_term_days: 0,\n        object: \"customer\",\n        pii_cleared: \"active\",\n        preferred_currency_code: \"EUR\",\n        promotional_credits: 0,\n        refundable_credits: 0,\n        resource_version: 1648489755361,\n        resources: %{\n          \"card\" => %Chargebeex.Card{\n            billing_addr1: \"my_address\",\n            billing_addr2: nil,\n            billing_city: \"Paris\",\n            billing_country: \"FR\",\n            billing_state: nil,\n            billing_state_code: nil,\n            billing_zip: \"12345\",\n            card_type: \"visa\",\n            created_at: 1648490053,\n            customer_id: \"169ljDT1Op0yuxET\",\n            expiry_month: 12,\n            expiry_year: 2023,\n            first_name: \"John\",\n            funding_type: \"credit\",\n            gateway: \"chargebee\",\n            gateway_account_id: \"gw_AzqPCGS1aaz5K3b\",\n            iin: \"411111\",\n            ip_address: nil,\n            issuing_country: nil,\n            last4: \"1111\",\n            last_name: \"M\",\n            masked_number: \"************1111\",\n            object: \"card\",\n            payment_source_id: \"pm_AzqYbtT1OqGcr5B1\",\n            powered_by: nil,\n            ref_tx_id: nil,\n            resource_version: 1648490053804,\n            status: \"valid\",\n            updated_at: 1648490053\n          }\n        },\n        taxability: \"taxable\",\n        unbilled_charges: 0,\n        updated_at: 1648489755\n        }}","ref":"Chargebeex.Customer.html#update/2-examples"},{"type":"function","title":"Chargebeex.Customer.update/3","doc":"","ref":"Chargebeex.Customer.html#update/3"},{"type":"function","title":"Chargebeex.Customer.update_billing_info/3","doc":"","ref":"Chargebeex.Customer.html#update_billing_info/3"},{"type":"function","title":"Chargebeex.Customer.update_hierarchy_settings/3","doc":"","ref":"Chargebeex.Customer.html#update_hierarchy_settings/3"},{"type":"function","title":"Chargebeex.Customer.update_payment_method/3","doc":"","ref":"Chargebeex.Customer.html#update_payment_method/3"},{"type":"module","title":"Chargebeex.CustomerEntitlement","doc":"Struct that represent a Chargebee's API customer entitlement resource.","ref":"Chargebeex.CustomerEntitlement.html"},{"type":"function","title":"Chargebeex.CustomerEntitlement.build/2","doc":"","ref":"Chargebeex.CustomerEntitlement.html#build/2"},{"type":"function","title":"Chargebeex.CustomerEntitlement.list/3","doc":"Allows to list Customer Entitlements\n\nAvailable filters can be found here: https://apidocs.chargebee.com/docs/api/customer_entitlements#list_customer_entitlements","ref":"Chargebeex.CustomerEntitlement.html#list/3"},{"type":"function","title":"Examples - Chargebeex.CustomerEntitlement.list/3","doc":"iex> filters = %{limit: 2}\n    iex(2)> Chargebeex.CustomerEntitlement.list(filters)\n    {:ok, [%Chargebeex.CustomerEntitlement{...}, %Chargebeex.CustomerEntitlement{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.CustomerEntitlement.html#list/3-examples"},{"type":"type","title":"Chargebeex.CustomerEntitlement.t/0","doc":"","ref":"Chargebeex.CustomerEntitlement.html#t:t/0"},{"type":"module","title":"Chargebeex.EntitlementOverride","doc":"Struct that represent a Chargebee's API entitlement override resource.","ref":"Chargebeex.EntitlementOverride.html"},{"type":"function","title":"Chargebeex.EntitlementOverride.build/2","doc":"","ref":"Chargebeex.EntitlementOverride.html#build/2"},{"type":"type","title":"Chargebeex.EntitlementOverride.entitlement_override/0","doc":"A single entitlement override map.","ref":"Chargebeex.EntitlementOverride.html#t:entitlement_override/0"},{"type":"type","title":"Chargebeex.EntitlementOverride.entity_type/0","doc":"\"subscription\"","ref":"Chargebeex.EntitlementOverride.html#t:entity_type/0"},{"type":"type","title":"Chargebeex.EntitlementOverride.t/0","doc":"","ref":"Chargebeex.EntitlementOverride.html#t:t/0"},{"type":"function","title":"Chargebeex.EntitlementOverride.upsert_or_remove/3","doc":"Upserts or removes a set of entitlement_overrides for a subscription depending on the action specified\n\nMore info: https://apidocs.eu.chargebee.com/docs/api/entitlement_overrides?lang=curl#upsert/remove_entitlement_overrides_for_a_subscription","ref":"Chargebeex.EntitlementOverride.html#upsert_or_remove/3"},{"type":"function","title":"Examples - Chargebeex.EntitlementOverride.upsert_or_remove/3","doc":"iex(1)> subscription_id = \"BTLybZUInBGCXDMY\"\n  \"BTLybZUInBGCXDMY\"\n  iex(2)> params = %{\n  ...(2)>   \"action\" => :upsert,\n  ...(2)>   \"entitlement_overrides\" => [\n  ...(2)>     %{\n  ...(2)>       \"feature_id\" => \"foo\",\n  ...(2)>       \"value\" => \"false\"\n  ...(2)>     }\n  ...(2)>   ]\n  ...(2)> }\n  %{\n    \"action\" => :upsert,\n    \"entitlement_overrides\" => [\n      %{\"feature_id\" => \"foo\", \"value\" => \"false\"}\n    ]\n  }\n  iex(3)> Chargebeex.EntitlementOverride.upsert_or_remove(subscription_id, params)\n  {:ok,\n   [\n     %Chargebeex.EntitlementOverride{...}\n   ], %{\"next_offset\" => nil}}","ref":"Chargebeex.EntitlementOverride.html#upsert_or_remove/3-examples"},{"type":"type","title":"Chargebeex.EntitlementOverride.upsert_or_remove_params/0","doc":"Parameters for the `upsert_or_remove` function.\nThe `action` field must be either `upsert` or `remove`.","ref":"Chargebeex.EntitlementOverride.html#t:upsert_or_remove_params/0"},{"type":"module","title":"Chargebeex.Event","doc":"","ref":"Chargebeex.Event.html"},{"type":"function","title":"Chargebeex.Event.build/1","doc":"","ref":"Chargebeex.Event.html#build/1"},{"type":"function","title":"Chargebeex.Event.build/2","doc":"","ref":"Chargebeex.Event.html#build/2"},{"type":"function","title":"Chargebeex.Event.list/2","doc":"","ref":"Chargebeex.Event.html#list/2"},{"type":"function","title":"Chargebeex.Event.retrieve/2","doc":"","ref":"Chargebeex.Event.html#retrieve/2"},{"type":"type","title":"Chargebeex.Event.t/0","doc":"","ref":"Chargebeex.Event.html#t:t/0"},{"type":"module","title":"Chargebeex.HostedPage","doc":"","ref":"Chargebeex.HostedPage.html"},{"type":"function","title":"Chargebeex.HostedPage.build/2","doc":"","ref":"Chargebeex.HostedPage.html#build/2"},{"type":"function","title":"Chargebeex.HostedPage.checkout_existing_for_items/2","doc":"Creates a Chargebee hosted page to accept payment details from a customer\nand checkout to update the subscription.","ref":"Chargebeex.HostedPage.html#checkout_existing_for_items/2"},{"type":"function","title":"Examples - Chargebeex.HostedPage.checkout_existing_for_items/2","doc":"iex> Chargebeex.HostedPage.checkout_existing_for_items(%{\n      subscription: %{id: \"subscription_id\"},\n      layout: \"in_app\",\n      subscription_items: [\n        %{item_price_id: \"item_price_id\", quantity: 1}\n      ]\n    })\n    {:ok, %Chargebeex.HostedPage{}}","ref":"Chargebeex.HostedPage.html#checkout_existing_for_items/2-examples"},{"type":"function","title":"Chargebeex.HostedPage.collect_now/2","doc":"Creates a Chargebee hosted page to collect due payments from a customer","ref":"Chargebeex.HostedPage.html#collect_now/2"},{"type":"function","title":"Examples - Chargebeex.HostedPage.collect_now/2","doc":"iex> Chargebeex.HostedPage.collect_now(%{\n      customer: %{\n        id: \"customer_id\"\n      },\n      card: %{\n        gateway_account_id: \"gateway_account_id\"\n      }\n    })\n    {:ok, %Chargebeex.HostedPage{}}","ref":"Chargebeex.HostedPage.html#collect_now/2-examples"},{"type":"function","title":"Chargebeex.HostedPage.list/2","doc":"","ref":"Chargebeex.HostedPage.html#list/2"},{"type":"function","title":"Chargebeex.HostedPage.retrieve/2","doc":"","ref":"Chargebeex.HostedPage.html#retrieve/2"},{"type":"type","title":"Chargebeex.HostedPage.t/0","doc":"","ref":"Chargebeex.HostedPage.html#t:t/0"},{"type":"module","title":"Chargebeex.Invoice","doc":"","ref":"Chargebeex.Invoice.html"},{"type":"function","title":"Chargebeex.Invoice.build/2","doc":"","ref":"Chargebeex.Invoice.html#build/2"},{"type":"function","title":"Chargebeex.Invoice.create/2","doc":"","ref":"Chargebeex.Invoice.html#create/2"},{"type":"function","title":"Chargebeex.Invoice.create_for_charge_items_and_charges/2","doc":"Creates an invoice for charge-items and one-time charges.","ref":"Chargebeex.Invoice.html#create_for_charge_items_and_charges/2"},{"type":"function","title":"Examples - Chargebeex.Invoice.create_for_charge_items_and_charges/2","doc":"iex> Chargebeex.Invoice.create_for_charge_items_and_charges(%{\n      customer_id: \"__test__KyVkkWS1xLskm8\",\n      item_prices: [\n        %{\n          item_price_id: \"ssl-charge-USD\",\n          unit_price: 2000\n        }\n      ]\n    })\n    {:ok, %Chargebeex.Invoice{}}","ref":"Chargebeex.Invoice.html#create_for_charge_items_and_charges/2-examples"},{"type":"function","title":"Chargebeex.Invoice.delete/2","doc":"","ref":"Chargebeex.Invoice.html#delete/2"},{"type":"function","title":"Chargebeex.Invoice.list/2","doc":"","ref":"Chargebeex.Invoice.html#list/2"},{"type":"function","title":"Chargebeex.Invoice.retrieve/2","doc":"","ref":"Chargebeex.Invoice.html#retrieve/2"},{"type":"type","title":"Chargebeex.Invoice.t/0","doc":"","ref":"Chargebeex.Invoice.html#t:t/0"},{"type":"function","title":"Chargebeex.Invoice.update/3","doc":"","ref":"Chargebeex.Invoice.html#update/3"},{"type":"module","title":"Chargebeex.Item","doc":"Struct that represent a Chargebee's API item resource.","ref":"Chargebeex.Item.html"},{"type":"function","title":"Chargebeex.Item.build/1","doc":"","ref":"Chargebeex.Item.html#build/1"},{"type":"function","title":"Chargebeex.Item.build/2","doc":"","ref":"Chargebeex.Item.html#build/2"},{"type":"type","title":"Chargebeex.Item.channel/0","doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.Item.html#t:channel/0"},{"type":"function","title":"Chargebeex.Item.create/2","doc":"","ref":"Chargebeex.Item.html#create/2"},{"type":"function","title":"Chargebeex.Item.delete/2","doc":"","ref":"Chargebeex.Item.html#delete/2"},{"type":"type","title":"Chargebeex.Item.item_applicability/0","doc":"\"all\" | \"restricted\"","ref":"Chargebeex.Item.html#t:item_applicability/0"},{"type":"function","title":"Chargebeex.Item.list/2","doc":"","ref":"Chargebeex.Item.html#list/2"},{"type":"function","title":"Chargebeex.Item.retrieve/2","doc":"","ref":"Chargebeex.Item.html#retrieve/2"},{"type":"type","title":"Chargebeex.Item.status/0","doc":"\"active\" | \"archived\" | \"deleted\"","ref":"Chargebeex.Item.html#t:status/0"},{"type":"type","title":"Chargebeex.Item.t/0","doc":"","ref":"Chargebeex.Item.html#t:t/0"},{"type":"type","title":"Chargebeex.Item.type/0","doc":"\"plan\" | \"addon\" | \"charge\"","ref":"Chargebeex.Item.html#t:type/0"},{"type":"function","title":"Chargebeex.Item.update/3","doc":"","ref":"Chargebeex.Item.html#update/3"},{"type":"type","title":"Chargebeex.Item.usage_calculation/0","doc":"\"sum_of_usages\" | \"last_usage\" | \"max_usage\"","ref":"Chargebeex.Item.html#t:usage_calculation/0"},{"type":"module","title":"Chargebeex.ItemPrice","doc":"Struct that represent a Chargebee's API item price resource.","ref":"Chargebeex.ItemPrice.html"},{"type":"function","title":"Chargebeex.ItemPrice.build/2","doc":"","ref":"Chargebeex.ItemPrice.html#build/2"},{"type":"type","title":"Chargebeex.ItemPrice.channel/0","doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.ItemPrice.html#t:channel/0"},{"type":"function","title":"Chargebeex.ItemPrice.create/2","doc":"","ref":"Chargebeex.ItemPrice.html#create/2"},{"type":"function","title":"Chargebeex.ItemPrice.delete/2","doc":"","ref":"Chargebeex.ItemPrice.html#delete/2"},{"type":"type","title":"Chargebeex.ItemPrice.item_applicability/0","doc":"\"all\" | \"restricted\"","ref":"Chargebeex.ItemPrice.html#t:item_applicability/0"},{"type":"function","title":"Chargebeex.ItemPrice.list/2","doc":"","ref":"Chargebeex.ItemPrice.html#list/2"},{"type":"type","title":"Chargebeex.ItemPrice.period_unit/0","doc":"\"day\" | \"week\" | \"month\" | \"year\"","ref":"Chargebeex.ItemPrice.html#t:period_unit/0"},{"type":"type","title":"Chargebeex.ItemPrice.pricing_model/0","doc":"\"flat_fee\" | \"per_unit\" | \"tiered\" | \"volume\" | \"stairstep\"","ref":"Chargebeex.ItemPrice.html#t:pricing_model/0"},{"type":"function","title":"Chargebeex.ItemPrice.retrieve/2","doc":"","ref":"Chargebeex.ItemPrice.html#retrieve/2"},{"type":"type","title":"Chargebeex.ItemPrice.status/0","doc":"\"active\" | \"archived\" | \"deleted\"","ref":"Chargebeex.ItemPrice.html#t:status/0"},{"type":"type","title":"Chargebeex.ItemPrice.t/0","doc":"","ref":"Chargebeex.ItemPrice.html#t:t/0"},{"type":"type","title":"Chargebeex.ItemPrice.trial_end_action/0","doc":"\"site_default\" | \"activate_subscription\" | \"cancel_subscription\"","ref":"Chargebeex.ItemPrice.html#t:trial_end_action/0"},{"type":"type","title":"Chargebeex.ItemPrice.type/0","doc":"\"plan\" | \"addon\" | \"charge\"","ref":"Chargebeex.ItemPrice.html#t:type/0"},{"type":"function","title":"Chargebeex.ItemPrice.update/3","doc":"","ref":"Chargebeex.ItemPrice.html#update/3"},{"type":"module","title":"Chargebeex.PaymentSource","doc":"","ref":"Chargebeex.PaymentSource.html"},{"type":"function","title":"Chargebeex.PaymentSource.build/2","doc":"","ref":"Chargebeex.PaymentSource.html#build/2"},{"type":"function","title":"Chargebeex.PaymentSource.create_bank_account/2","doc":"","ref":"Chargebeex.PaymentSource.html#create_bank_account/2"},{"type":"function","title":"Chargebeex.PaymentSource.create_card/2","doc":"","ref":"Chargebeex.PaymentSource.html#create_card/2"},{"type":"function","title":"Chargebeex.PaymentSource.delete/2","doc":"","ref":"Chargebeex.PaymentSource.html#delete/2"},{"type":"function","title":"Chargebeex.PaymentSource.list/2","doc":"","ref":"Chargebeex.PaymentSource.html#list/2"},{"type":"function","title":"Chargebeex.PaymentSource.retrieve/2","doc":"","ref":"Chargebeex.PaymentSource.html#retrieve/2"},{"type":"type","title":"Chargebeex.PaymentSource.t/0","doc":"","ref":"Chargebeex.PaymentSource.html#t:t/0"},{"type":"module","title":"Chargebeex.PortalSession","doc":"","ref":"Chargebeex.PortalSession.html"},{"type":"function","title":"Chargebeex.PortalSession.activate/3","doc":"When an user is sent back to your return URL with session details, you\n  should validate that information by calling this API.","ref":"Chargebeex.PortalSession.html#activate/3"},{"type":"function","title":"Chargebeex.PortalSession.build/2","doc":"","ref":"Chargebeex.PortalSession.html#build/2"},{"type":"function","title":"Chargebeex.PortalSession.create/2","doc":"","ref":"Chargebeex.PortalSession.html#create/2"},{"type":"function","title":"Chargebeex.PortalSession.logout/2","doc":"Logs out the portal session. This should be called when customers logout of\n  your application.","ref":"Chargebeex.PortalSession.html#logout/2"},{"type":"function","title":"Chargebeex.PortalSession.retrieve/2","doc":"","ref":"Chargebeex.PortalSession.html#retrieve/2"},{"type":"type","title":"Chargebeex.PortalSession.t/0","doc":"","ref":"Chargebeex.PortalSession.html#t:t/0"},{"type":"module","title":"Chargebeex.Quote","doc":"Struct that represent a Chargebee's API quote.","ref":"Chargebeex.Quote.html"},{"type":"function","title":"Chargebeex.Quote.build/2","doc":"","ref":"Chargebeex.Quote.html#build/2"},{"type":"function","title":"Chargebeex.Quote.edit_create_subscription_quote_for_items/3","doc":"Changes the quote produced for creating a new subscription items\n  (operation_type = `create_subscription_for_customer`)","ref":"Chargebeex.Quote.html#edit_create_subscription_quote_for_items/3"},{"type":"function","title":"Chargebeex.Quote.edit_for_charge_items_and_charges/3","doc":"Changes the quote produced for adding one-time charges and charge items.\n  (operation_type = `onetime_invoice`)","ref":"Chargebeex.Quote.html#edit_for_charge_items_and_charges/3"},{"type":"function","title":"Chargebeex.Quote.edit_update_subscription_quote_for_items/3","doc":"Changes the quote produced for updating the subscription items.\n  (operation_type = `change_subscription`)","ref":"Chargebeex.Quote.html#edit_update_subscription_quote_for_items/3"},{"type":"function","title":"Chargebeex.Quote.list/2","doc":"","ref":"Chargebeex.Quote.html#list/2"},{"type":"type","title":"Chargebeex.Quote.operation_type/0","doc":"\"create_subscription_for_customer\" | \"change_subscription\" | \"onetime_invoice\"","ref":"Chargebeex.Quote.html#t:operation_type/0"},{"type":"type","title":"Chargebeex.Quote.price_type/0","doc":"\"tax_exclusive\" | \"tax_inclusive\"","ref":"Chargebeex.Quote.html#t:price_type/0"},{"type":"function","title":"Chargebeex.Quote.retrieve/2","doc":"","ref":"Chargebeex.Quote.html#retrieve/2"},{"type":"type","title":"Chargebeex.Quote.status/0","doc":"\"open\" | \"accepted\" | \"declined\" | \"invoiced\" | \"closed\"","ref":"Chargebeex.Quote.html#t:status/0"},{"type":"type","title":"Chargebeex.Quote.t/0","doc":"","ref":"Chargebeex.Quote.html#t:t/0"},{"type":"module","title":"Chargebeex.Subscription","doc":"","ref":"Chargebeex.Subscription.html"},{"type":"function","title":"Chargebeex.Subscription.build/1","doc":"","ref":"Chargebeex.Subscription.html#build/1"},{"type":"function","title":"Chargebeex.Subscription.build/2","doc":"","ref":"Chargebeex.Subscription.html#build/2"},{"type":"type","title":"Chargebeex.Subscription.cancel_reason/0","doc":"\"not_paid\" | \"no_card\" | \"fraud_review_failed\" | \"non_compliant_eu_customer\" | \"tax_calculation_failed\" | \"currency_incompatible_with_gateway\" | \"non_compliant_customer\"","ref":"Chargebeex.Subscription.html#t:cancel_reason/0"},{"type":"type","title":"Chargebeex.Subscription.channel/0","doc":"\"web\" | \"app_store\" | \"play_store\"","ref":"Chargebeex.Subscription.html#t:channel/0"},{"type":"function","title":"Chargebeex.Subscription.create_with_items/3","doc":"Creates a Subcription with items for a Customer","ref":"Chargebeex.Subscription.html#create_with_items/3"},{"type":"function","title":"Examples - Chargebeex.Subscription.create_with_items/3","doc":"iex> Chargebeex.Subscription.create_with_items(\"169ljDT1Op0yuxET\", %{\n               subscription_items: [\n                 %{\n                   item_price_id: \"DEF789LMN012\",\n                   quantity: 1\n                 }\n               ]\n             })\n    {:ok, %Chargebeex.Subscription{\n        subscription_items: [\n          %{\n            \"amount\" => 100,\n            \"free_quantity\" => 0,\n            \"item_price_id\" => \"DEF789LMN012\",\n            \"item_type\" => \"plan\",\n            \"object\" => \"subscription_item\",\n            \"quantity\" => 1,\n            \"trial_end\" => 1705877999,\n            \"unit_price\" => 100\n          }\n        ],\n        customer_id: \"169ljDT1Op0yuxET\",\n        ...\n      }}","ref":"Chargebeex.Subscription.html#create_with_items/3-examples"},{"type":"function","title":"Chargebeex.Subscription.list/2","doc":"","ref":"Chargebeex.Subscription.html#list/2"},{"type":"type","title":"Chargebeex.Subscription.period_unit/0","doc":"\"day\" | \"week\" | \"month\" | \"year\"","ref":"Chargebeex.Subscription.html#t:period_unit/0"},{"type":"function","title":"Chargebeex.Subscription.retrieve/2","doc":"","ref":"Chargebeex.Subscription.html#retrieve/2"},{"type":"type","title":"Chargebeex.Subscription.status/0","doc":"\"future\" | \"in_trial\" | \"active\" | \"non_renewing\" | \"paused\" | \"cancelled\"","ref":"Chargebeex.Subscription.html#t:status/0"},{"type":"type","title":"Chargebeex.Subscription.t/0","doc":"","ref":"Chargebeex.Subscription.html#t:t/0"},{"type":"type","title":"Chargebeex.Subscription.trial_end_action/0","doc":"\"site_default\" | \"plan_default\" | \"activate_subscription\" | \"cancel_subscription\"","ref":"Chargebeex.Subscription.html#t:trial_end_action/0"},{"type":"function","title":"Chargebeex.Subscription.update/3","doc":"","ref":"Chargebeex.Subscription.html#update/3"},{"type":"function","title":"Chargebeex.Subscription.update_for_items/3","doc":"","ref":"Chargebeex.Subscription.html#update_for_items/3"},{"type":"module","title":"Chargebeex.SubscriptionEntitlement","doc":"Struct that represent a Chargebee's API subscription entitlement resource.","ref":"Chargebeex.SubscriptionEntitlement.html"},{"type":"function","title":"Chargebeex.SubscriptionEntitlement.build/2","doc":"","ref":"Chargebeex.SubscriptionEntitlement.html#build/2"},{"type":"type","title":"Chargebeex.SubscriptionEntitlement.feature_type/0","doc":"\"switch\" | \"custom\" | \"quantity\" | \"range\"","ref":"Chargebeex.SubscriptionEntitlement.html#t:feature_type/0"},{"type":"function","title":"Chargebeex.SubscriptionEntitlement.list/3","doc":"Allows to list Subscription Entitlements\n\nAvailable filters can be found here: https://apidocs.chargebee.com/docs/api/subscription_entitlements#list_subscription_entitlements","ref":"Chargebeex.SubscriptionEntitlement.html#list/3"},{"type":"function","title":"Examples - Chargebeex.SubscriptionEntitlement.list/3","doc":"iex> filters = %{limit: 2}\n    iex(2)> Chargebeex.SubscriptionEntitlement.list(filters)\n    {:ok, [%Chargebeex.SubscriptionEntitlement{...}, %Chargebeex.SubscriptionEntitlement{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.SubscriptionEntitlement.html#list/3-examples"},{"type":"function","title":"Chargebeex.SubscriptionEntitlement.set_availability/3","doc":"Enables or disables specific subscription_entitlements for a subscription.\n\n\nFor more info, check the API doc: https://apidocs.eu.chargebee.com/docs/api/subscription_entitlements?lang=curl#enable/disable_subscription_entitlements","ref":"Chargebeex.SubscriptionEntitlement.html#set_availability/3"},{"type":"function","title":"Examples - Chargebeex.SubscriptionEntitlement.set_availability/3","doc":"#\n    iex(1)> subscription_id = \"BTLybZUInBGCXDMY\"\n    \"BTLybZUInBGCXDMY\"\n    iex(2)> params = %{\n    ...(2)>   \"is_enabled\" => true,\n    ...(2)>   \"subscription_entitlements\" => [\n    ...(2)>     %{\n    ...(2)>       \"feature_id\" => \"foo_feature\"\n    ...(2)>     }\n    ...(2)>   ]\n    ...(2)> }\n    %{\n      \"is_enabled\" => true,\n      \"subscription_entitlements\" => [\n        %{\"feature_id\" => \"foo_feature\"}\n      ]\n    }\n    iex(3)> Chargebeex.SubscriptionEntitlement.set_availability(subscription_id, params)\n    {:ok,\n     [%Chargebeex.SubscriptionEntitlement{...}], %{\"next_offset\" => nil}}","ref":"Chargebeex.SubscriptionEntitlement.html#set_availability/3-examples"},{"type":"type","title":"Chargebeex.SubscriptionEntitlement.set_availability_params/0","doc":"Parameters for the `set_availability` function.","ref":"Chargebeex.SubscriptionEntitlement.html#t:set_availability_params/0"},{"type":"type","title":"Chargebeex.SubscriptionEntitlement.subscription_entitlement/0","doc":"A single subscription entitlement map.","ref":"Chargebeex.SubscriptionEntitlement.html#t:subscription_entitlement/0"},{"type":"type","title":"Chargebeex.SubscriptionEntitlement.t/0","doc":"","ref":"Chargebeex.SubscriptionEntitlement.html#t:t/0"},{"type":"module","title":"Chargebeex.Usage","doc":"Struct that represent a Chargebee's API usage resource.","ref":"Chargebeex.Usage.html"},{"type":"function","title":"Chargebeex.Usage.build/2","doc":"","ref":"Chargebeex.Usage.html#build/2"},{"type":"function","title":"Chargebeex.Usage.create/3","doc":"Allows to create a Usage","ref":"Chargebeex.Usage.html#create/3"},{"type":"function","title":"Examples - Chargebeex.Usage.create/3","doc":"iex> Chargebeex.Usage.create(\"e49e39cf-a406-4cc9-b14a-85476b3c3ebf\", %{item_price_id: \"item_eur_monthly\", quantity: 42, usage_date: 1599817250})\n      {:ok, %Chargebeex.Usage{}}","ref":"Chargebeex.Usage.html#create/3-examples"},{"type":"function","title":"Chargebeex.Usage.delete/3","doc":"Allows to delete a Usage","ref":"Chargebeex.Usage.html#delete/3"},{"type":"function","title":"Examples - Chargebeex.Usage.delete/3","doc":"iex> Chargebeex.Usage.delete(\"e49e39cf-a406-4cc9-b14a-85476b3c3ebf\", %{id: \"a065d78c-a5a8-458b-85b6-e9295118d3bf\"})\n      {:ok, %Chargebeex.Usage{}}","ref":"Chargebeex.Usage.html#delete/3-examples"},{"type":"function","title":"Chargebeex.Usage.list/2","doc":"","ref":"Chargebeex.Usage.html#list/2"},{"type":"function","title":"Chargebeex.Usage.retrieve/3","doc":"Allows to retrieve a Usage","ref":"Chargebeex.Usage.html#retrieve/3"},{"type":"function","title":"Examples - Chargebeex.Usage.retrieve/3","doc":"iex> Chargebeex.Usage.retrieve(\"e49e39cf-a406-4cc9-b14a-85476b3c3ebf\", %{id: \"a065d78c-a5a8-458b-85b6-e9295118d3bf\"})\n      {:ok, %Chargebeex.Usage{}}","ref":"Chargebeex.Usage.html#retrieve/3-examples"},{"type":"type","title":"Chargebeex.Usage.source/0","doc":"\"admin_console\" | \"api\" | \"bulk_operation\"","ref":"Chargebeex.Usage.html#t:source/0"},{"type":"type","title":"Chargebeex.Usage.t/0","doc":"","ref":"Chargebeex.Usage.html#t:t/0"},{"type":"extras","title":"Overview","doc":"# Chargebeex\n\nChargebeex is an Elixir implementation of [Chargebee\nAPI](https://apidocs.chargebee.com/docs/api).\n\nThis is a heavily inspired fork of the original work by [Nicolas\nMarlier](https://github.com/NicolasMarlier/chargebee-elixir)","ref":"readme.html"},{"type":"extras","title":"Project status - Overview","doc":"Chargebeex is used for several months in production at Welcome to the Jungle.","ref":"readme.html#project-status"},{"type":"extras","title":"Installation - Overview","doc":"The package can be installed by adding `chargebeex` to your list of dependencies in `mix.exs`:\n\n```elixir\n# mix.exs\ndef deps do\n  [\n    {:chargebeex, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"Chargebeex can be configured using [Config](https://hexdocs.pm/elixir/1.12/Config.html) or environment variables.","ref":"readme.html#configuration"},{"type":"extras","title":"Config - Overview","doc":"```elixir\nconfig :chargebeex,\n  namespace: \"my-namespace\",\n  api_key: \"my-api-key\"\n```","ref":"readme.html#config"},{"type":"extras","title":"Environment variables - Overview","doc":"```\nexport CHARGEBEEX_API_KEY=my-api-key\nexport CHARGEBEEX_NAMESPACE=my-namespace\n```","ref":"readme.html#environment-variables"},{"type":"extras","title":"Usage - Overview","doc":"```elixir\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.retrieve(\"foobar\")\n{:ok, [%Chargebeex.Customer{}], [%Chargebeex.Customer{}]} = Chargebeex.Customer.list()\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.update(\"foobar\", %{name: \"updated\"})\n{:ok, %Chargebeex.Customer{}} = Chargebeex.Customer.delete(\"foobar\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Custom Fields - Overview","doc":"Chargebee provides a way to add user-specific fields for resources like\nCustomer, Subscriptions, ... called [Custom\nFields](https://www.chargebee.com/docs/2.0/custom_fields.html).\n\nThese fields are prepended with the `cf_` prefix. These fields can be accessed\nin the special `custom_fields` field of the structure. Please note Custom Fields\nare only available for Customers, Subscriptions, Product Families, Plans,\nAddons and Price Points.\n\n#### Example:\n\n```elixir\n iex> Chargebeex.Customer.retrieve(\"barbaz\")\n {:ok, %Chargebeex.Customer{\n     id: \"barbaz\",\n     allow_direct_debit: false,\n     custom_fields: %{\n       \"cf_my_custom_field\" => \"foobar\"\n     },\n     [...]}\n  }\n```","ref":"readme.html#custom-fields"},{"type":"extras","title":"Extra Resources - Overview","doc":"Some ressources can have extra infos returned along them. For example, when\nquerying a Customer, if any card or subscription is linked to this customer,\nthese resources will also be returned. For internal API simplification, these\nfields can be accessed in the `resources` field of the structure.\n\n#### Example:\n\n```elixir\n iex> Chargebeex.Customer.retrieve(\"barbaz\")\n {:ok, %Chargebeex.Customer{\n     id: \"barbaz\",\n     allow_direct_debit: false,\n      resources: %{\n        \"card\" => %Chargebeex.Card{\n          billing_addr1: \"my_address\",\n          billing_addr2: nil,\n          billing_city: \"Paris\",\n          ...\n          }\n      }\n     [...]}\n  }\n```","ref":"readme.html#extra-resources"},{"type":"extras","title":"Telemetry Integration - Overview","doc":"Chargebeex now supports `:telemetry`, allowing users to instrument and monitor API calls using telemetry events. This enables integration with various observability tools.\n\n#### Telemetry Events\n\nChargebeex emits the following telemetry events for each API request:\n\n- `[:chargebeex, :request, :start]`: Emitted when an API request starts.\n- `[:chargebeex, :request, :stop]`: Emitted when an API request completes.\n\nWhen making API calls, telemetry events will automatically be emitted:\n\n```elixir\nChargebeex.Client.get(\"/customers\")\n```\n\nThis will emit :start and :stop telemetry events with metadata such as the HTTP method, URL, and status code, which can be processed by your telemetry handler.\n\nFor more information on `:telemetry`, visit the [official documentation](https://hexdocs.pm/telemetry/).","ref":"readme.html#telemetry-integration"},{"type":"extras","title":"Run tests - Overview","doc":"```sh\nmix test\n```","ref":"readme.html#run-tests"},{"type":"extras","title":"License - Overview","doc":"MIT","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}